Introduction
============

The ``ox_secrets`` package provides a simple secret server for python.
You can use simple file based secret storage in development and testing
and then add more sophisticated secret storage in production.

Think of it similar to an ORM for secrets.
